clc 
clear all
%% Finding beam elements to load during well intervention
% Due to symmetry, only the North-East quadrant of the topside deck is
% considered. Though the load could be moved past y<0 to get heavy loading
% of the column at y=0

rectangledim= [20 10];                    %Width(W-E) and length(S-S) of 
                                        %the "container rectangle"
sw_corner = [-10 0];                      %South-west corner of rectangle
ne_corner = sw_corner + rectangledim;   %North-east corner of rectangle

ldcase = 3;                             %loadcase number used in USFOS

equip_weight = 150*10^3;                %[kg] well intervention equipment
g = 9.81;                               %[N/kg] Gravitational acceleration
elem_l = 0.5;                           %[m] all beam elements on north-
                                        %east quadrant are 0.5m of length

%% Calculating and writes load data to a load file. 
disp('reading data from spreadsheet...')
[nodearray, beamarray, beamvector] = nodes();
disp('done')
disp('writing load- and group definition...')
[writing] = writeload(nodearray, beamarray, beamvector, sw_corner, ne_corner,...
    ldcase, g, elem_l, equip_weight);
disp(writing);

%% Generating FAHTS fhead.fem parameters
% User defined parameters
length = 15;                        %[m] Jet length
start_dir = 279;                    %[deg] Anti-cl.wise from pos. x dir.
resolution = 63;                    %[deg] Uniform distr # of directions(63)
coor_origin = [3 3 1];            %[m] Placement of "gas leak"
end_height = 2;                     %[m] Vertical dist. to jet end point 
intensity = 1.23E+06;               %[W/m] Heat intensity of jet
dinit = 2.5;                        %[m] Initial diameter of jet
dend = 2.5;                         %[m] End diameter of jet
end_time = 60;                      %[min] Duration of fahts analysis
resinc = 1;                       %[min] Time step length(no fancy step!)
endh = ldcase + (end_time/resinc);  %[#] Name of last temperature ldstep
disp('writing parameters for FAHTS head file')
[fahts] = writefahts(length, start_dir, resolution, coor_origin, end_height,...
    intensity, dinit, dend, end_time, resinc, endh);
disp(fahts);

%% Generating USFOS uhead.fem parameters
disp('writing parameters for USFOS head file')
[usfos] = writeusfos(ldcase, endh, resinc);
disp(usfos);


