%Function that writes parameter file for FAHTS jetfire analysis on basis of
%user's chosen flame origin, lenght, direction resolution, diameter, heat
%intensity, duration and length of time step.

function [fahts] = writefahts(length, start_dir, resolution, coor_origin,... 
    end_height, intensity, dinit, dend, end_time, resinc, endh)

%% Calculated parameters
proj_length = ...
    sqrt(length^2-end_height^2);     %[m] Jet projected to horiz plane
num_dir = 200/resolution;


end_coor = [];                       %Empty parameter matrix,
                                     %handy when writing to file 
%% Opening and writing to parameter file.
fileID = fopen('fahtsparam.dat','w');
% Naming the parameters. Used by BASH script to substitute parameters
fprintf(fileID,...
    '%6s %6s %6s %10s %6s %6s %6s %10s %6s %6s %12s %4s %6s %4s\n',...
    'xinit','yinit','zinit','hinit',...
    'xend','yend','zend','hend','inD','enD','jetdir','dur','tstep',...
    'lstT');
for i = 1:num_dir
    % Coordinates and heat intensity of jet origin point: 
    end_coor(i,1) = (coor_origin(1));
    end_coor(i,2) = (coor_origin(2));
    end_coor(i,3) = (coor_origin(3));
    end_coor(i,4) = round(intensity*100)/100;
    % Coordinates and heat intensity of jet end point: 
    end_coor(i,5) = round((coor_origin(1) +...
        proj_length*cosd(start_dir+(i*resolution)))*100)/100;
    end_coor(i,6) = round((coor_origin(2) +...
        proj_length*sind(start_dir + (i*resolution)))*100)/100;
    end_coor(i,7) = round((coor_origin(3) + end_height)*100)/100;
    end_coor(i,8) = intensity;
    % Diameter of jet origin and end points:
    end_coor(i,9) = dinit;
    end_coor(i,10) = dend;
    % Telling the header of FAHTS control file the resolution in degrees:
    end_coor(i,11) = mod(start_dir + (i*resolution),360);
    end_coor(i,12) = end_time;
    end_coor(i,13) = resinc;
    end_coor(i,14) = endh;
%     end_coor(i,15) = ldcase;
    % Writing each row of data in parameter matrix into a row in the
    % parameter file:
fprintf(fileID,...
    '%6g %6g %6g %10.2E %6g %6g %6g %10.2E %6g %6g %8g %6g %6g %6g\n',...
    end_coor(i,:));
end
% Closing and saving the parameter file:
fclose(fileID);
fahts = 'done';
end