% Function that takes data gathered from the spreadsheet, compares with the
% chosen "load rectangle", picks out the correct beam elements, calculates
% load intensity and writes to a load file. A group file is also written,
% to make the beam elements stand out in USFOS


function [writing] = writeload(nodearray, beamarray, beamvector, sw_corner,...
    ne_corner, ldcase, g, elem_l, equip_weight)

nodelist = [];                          %Empty array to be filled
counter = 1;                            %Help counter
ac = 0.001;                             %Accuracy helper. 
% Go through the array of node data
for i = 1:length(nodearray)
    % If the node has coordinates inside the lode rectangle it is stored in
    % the "nodelist" array
    if nodearray(i,2)>=(sw_corner(1)-ac) &&...
            nodearray(i,2)<=(ne_corner(1)+ac) &&...
            nodearray(i,3)>=(sw_corner(2)-ac) &&...
            nodearray(i,3)<=(ne_corner(2)+ac)
        nodelist(counter,:) = nodearray(i,:);
        counter = counter+1;
    end
end

beamlist = [];                          %Empty vector to be filled
counter = 1;                            %Help counter reset
% Go through the array of topside beams
for j = 1:length(beamarray)
    % If BOTH end node numbers of a beam element exist in the "nodelist"
    % the beam element number is stored in the "beamlist"
    if ismember(beamarray(j,2),nodelist(:,1)) &&...
            ismember(beamarray(j,3),nodelist(:,1))
        beamlist(counter,1) = beamarray(j,1);
        counter = counter + 1;
    end
end

load_beams = [];                        %Empty vector to be filled
counter = 1;                            %Help counter reset
% Go through beamlist vector
for k = 1:length(beamlist)
    % If the beam element exist in the "beamvector" it is east-west
    % orientated, thus it gets stored in the "load_beams" vector
    if ismember(beamlist(k),beamvector)
        load_beams(counter) = beamlist(k);
        counter = counter + 1;
    end
end

%% Load calculation
% Assuming load is uniformly distributed over the loaded beams

numb_beams = length(load_beams);        %Get the number of loaded beams
tot_length = elem_l*numb_beams;         %Total length of loaded beams



force_eq = equip_weight*g;              %[N] vertical force of the load
load_int = force_eq/tot_length;         %[N/m] Uniform dist. line load

%% Write to load file
ldarray = zeros(numb_beams,5);
%% Opening and writing to parameter file.
ldfile = fopen('../loads/inter_load.dat','w');
% Naming the parameters. Used by BASH script to substitute parameters
fprintf(ldfile,'%-6s %6s %6s %6s %6s %6s %8s\n',...
    '#','ldCase','ElemID','Xint','Yint','Zint');
    fprintf(ldfile,'%-8s\n','#');         %Cheat to force a new line
for i = 1:numb_beams
    ldarray(i,:) = [ldcase load_beams(i) 0 0 -load_int];
    fprintf(ldfile,'%-8s %4g %6g %6g %6g %9.4E\n','BEAMLOAD',ldarray(i,:));
end
fclose(ldfile);

%% Opening and writing to group file
grfile = fopen('../groups/inter_group.dat','w');
fprintf(grfile,'%-6s %5s %2s %6s %7s %5s\n',...
    '#','Group','of','loaded','topside','beams');
fprintf(grfile,'%5s %6s %10g %17s\n',...
    'Name','Group',ldcase,'Intervention_load');
fprintf(grfile,'%9s %13g %6s\n','GroupDef',ldcase,'Elem');
fprintf(grfile,'%24g\n',load_beams);
fclose(grfile);

writing = 'done';
end