#!/bin/bash
START_TIME=$SECONDS



# ---------- PARAMETERS ---------- #
INPUTFILE="./inputgen/fahtsparam.dat"     # The file containing the parameter data
THREADS=1                          # The number of parallel threads (0=auto)
LOADFILE="./loads/inter_load.dat"
GROUPFILE="./groups/inter_group.dat"
origModel="./MainModel.fem"
# -------------------------------- #
#######
# Make modelfile based on generated loads and groups
modelFile="assembledmodel.fem"
#	Copy geometry and material data from "MainModel.fem"
cp -a	"$origModel"			"$modelFile"
#
#	Adding load data from "loads" directory (imp is the imperfection dummy)
cat	loads/CellarLoads		>>	"$modelFile"
cat	loads/MezzanineLoads		>>	"$modelFile"
cat	loads/TopsideLoads		>>	"$modelFile"
cat	loads/gravity			>>	"$modelFile"
cat	loads/imp_load			>>	"$modelFile"
#
#	Adding the variable placement topside load
cat     "$LOADFILE"			>>	"$modelFile"
#
#
#	Adding element gruops
cat	groups/material3		>>	"$modelFile"	
cat	groups/material4		>>	"$modelFile"
cat	groups/material5		>>	"$modelFile"
cat	groups/truss			>>	"$modelFile"
cat	"$GROUPFILE"			>>	"$modelFile"
######
# Define a function used to initialize modules
function initialize {
  # Run all all scripts
  for MOD in ./programs/*
  do
    if [ -f $MOD -a -x $MOD ]; then
      $MOD init >> ./logs/init.log
    fi
  done
}

# Define function used to find what files that is going through subtitution
function findfiles {
  # Run all all scripts
  for MOD in ./programs/*
  do
    if [ -f $MOD -a -x $MOD ]; then
      $MOD files $1 | grep -v '^$' # The grep command is to remove empty lines
    fi
  done
}

# Do the postprocessing
function postp {
  # Go through all scripts
  for MOD in ./programs/*
  do
    if [ -f $MOD -a -x $MOD ]; then
      $MOD postp2 >> ./logs/postp2.log
    fi
  done
}

# Make a folder for the contents of the terminal logs
if [ ! -d logs ]; then
  mkdir logs
else
  rm logs/*.log
fi

# Do the initialization
echo -n "Initializing folders..."
initialize

echo "Done."
echo -n "Assembling input files..."

# Reads the first line of the input file to get the column headers
read -r FIRSTLINE < $INPUTFILE

# Finds the number of columns
FIELDS=`echo $FIRSTLINE | awk '{ print NF }'`

# Make an array with the column/field names
for i in `seq 1 $FIELDS`
do
  FIELD[$i]=`echo $FIRSTLINE | awk '{ print $c }' c=$i`
done

# Reads the parameter file line by line
LINE=0
COMMAND=""
while read INPUTLINE
do
  # Do not process the first line
  LINE=`expr $LINE + 1`
  if [ $LINE -eq 1 ]; then
    continue
  fi
  
  # Construct the case name/filename
  CASENAME=""
  ARRAY=(4 10 11)
  for i in ${ARRAY[*]}
  do
    VALUE=`echo $INPUTLINE | awk '{ print $c }' c=$i`
    CASENAME="${CASENAME}_${FIELD[$i]:0:4}_$VALUE"
  done
  CASENAME=${CASENAME:1}

  # Do the substitution process for all files returned by the modules
  while read INPOUT
  do
    # If empty string, continue loop
    if [ ${#INPOUT} -lt 3 ]; then
      continue
    fi
    
    # Define file names
    INPUT=`echo -n $INPOUT | awk '{ print $1; }'`
    OUTPUT=`echo -n $INPOUT | awk '{ print $2; }'`
    
    # Create folder for output file if it not exist
    OUTDIR=`dirname $OUTPUT`
    if [ ! -d $OUTDIR ]; then
      mkdir $OUTDIR
      mkdir $OUTDIR/pushdown
      cp fact.ctr $OUTDIR/pushdown/factcont.ctr
    fi
    
    # Copy original file to destination
    cp $INPUT $OUTPUT
    cp substitute2 $OUTDIR
    #cp substitute $OUTDIR/pushdown
    
   # pushdir="/runs/${CASENAME}/pushdown"
   # if [ ! -d "$pushdir" ]; then
   #   mkdir "$pushdir"
   # else
   #   rm "$pushdir"
   # fi
    
    # Substitution process for each field
    for i in `seq 1 $FIELDS`
    do
      VALUE=`echo $INPUTLINE | awk '{ print $c }' c=$i`
      
      # Substitute in header and model file
      ./substitute ${FIELD[$i]} $VALUE $OUTPUT
    done  
  done <<< "`findfiles $CASENAME`"
  
  # Putting the job in the command string
  COMMAND="${COMMAND}${CASENAME}\0"
done < "${INPUTFILE}"

# Find the number of threads your computer can run
if [ $THREADS -lt 1 ]; then
  THREADS=`cat /proc/cpuinfo | grep processor | wc -l`
fi

# Executing the commands in parallel
echo "Done."
echo "Running multiple analysises with $THREADS threads in parallel..."
echo -e $COMMAND | xargs -0 -n 1 -P $THREADS ./runone analyze
#var_path=`pwd`
echo $var_path



# Running postprocessing
echo "Parallel processing done."
echo "Running postprocessing tasks..."

# No paralell run of postprocessing
echo -e $COMMAND | xargs -0 -n 1 -P 1 ./runone postp1

# Final postprocessing
echo -n "Running final postprocessing..."
postp

rm "$modelFile"
ELAPSED_TIME=$(($SECONDS - $START_TIME))
echo "$ELAPSED_TIME"
echo "USFOS Done".