#!/bin/bash
#
upath='./../../../USFOS/bin/'
pathanalysis='./../../TopsideModel/Analyses/stepped/runs/'
UINPUT="./inputgen/usfosparam.dat"

# Define the input variables
if [ $# -eq 1 ]; then
  ACTION=$1
elif [ $# -eq 2 ]; then
  ACTION=$1
  CASENAME=$2
else
  echo "30-usfos: Invalid number of argumens supplied."
  exit
fi


# The initialization
if [ $ACTION == "init" ]; then
  echo "30-usfos: No initialization tasks done."
  exit


# Return the files to look for substitutions in
elif [ $ACTION == "files" -a $# -eq 2 ]; then
  echo "usfoshead.fem runs/$CASENAME/uhead.fem"
#  exit

# Do the individual analyses
elif [ $ACTION == "analyze" -a $# -eq 2 ]; then
  echo "30-usfos: Running analysis in Usfos."
  
read -r FIRSTROW < $UINPUT
COLUMNS=`echo $FIRSTROW | awk '{ print NF }'`
ROWS=`awk 'END {print NR}' "$UINPUT"`
  for i in `seq 1 $COLUMNS`
  do
    COLUMN[$i]=`echo $FIRSTROW | awk '{ print $c }' c=$i`
  done
  
 
 cd runs/$CASENAME/
LINE=0
for j in `seq 1 $ROWS`
do 
      read a
      # Do not process the first line
      LINE=`expr $LINE + 1`
      if [ $LINE -eq 1 ]; then
        continue
      fi
       
          # Copy the usfos head file into the pushdown folder
          ORIG="uhead.fem"
          COPY="pushdown/pushhead_$LINE.fem"
          
          cp $ORIG $COPY

                # Substitution process for each field
                  for k in `seq 1 $COLUMNS`
                  do
                     VALUE=`echo $a | awk '{ print $c }' c=$k`
                    # Substitute in header and model file
                    ./substitute2 ${COLUMN[$k]} $VALUE $COPY 
                  done  
  
done < "../../${UINPUT}"



cd -

MYDIR="runs"

DIRS=`ls -l $MYDIR | egrep '^d' | awk '{print $9}'`



cd ${upath}
for DIR in $DIRS
do     
      # Run the USFOS analysis
       for l in `seq 2 $ROWS`
         do
./usfos.exe<<EndIn
    ${pathanalysis}${DIR}/pushdown/pushhead_$l
    ${pathanalysis}${DIR}/model
    ${pathanalysis}${DIR}/fresult_beltemp
    ${pathanalysis}${DIR}/pushdown/${l}_uresult
EndIn
./fact.exe<<EndIn
${pathanalysis}${DIR}/pushdown/${l}_uresult.raf
${pathanalysis}${DIR}/pushdown/factcont.ctr
${pathanalysis}${DIR}/pushdown/elemforces_${l}
EndIn
         done
done
#  done
  # Return to base folder (previous folder)
  #cd -
#done < "${UINPUT}"

# Do postprocessing after individual run (for example to extract results)
elif [ $ACTION == "postp1" -a $# -eq 2 ]; then
  echo "30-usfos: No postprocessing tasks done."
  exit


# Do postprocessing after all individual runs (for example to do statistics)
elif [ $ACTION == "postp2" ]; then
  echo "30-usfos: No postprocessing tasks done."
  exit


# Else, do nothing
else
  echo "30-usfos: Invalid action argument supplied, or missing case name."
  exit
fi
